# v_PVMismatch
 Vectorized version of SunPower's PVMismatch using dynamic programming. PVMismatch is an explicit IV & PV curve trace calculator for PV system circuits.
 
## Install & Setup
In a fresh Python virtual environment, simply run:

```bash
$ pip install --index-url https://test.pypi.org/simple/ --extra-index-url https://pypi.org/simple v_PVMismatch
```

### Install using .whl file (Recommended)
Download files from Github and run the latest version of the .whl file using the command below from the parent folder.

```bash
$ pip install .\dist\v_PVMismatch-<version>-py3-none-any.whl
```

## Requirements

v_PVMismatch requires Matplotlib, Future, NumPy, and SciPy.

## Current Maintainer at Maxeon Solar

@k-bsub
